@@ -173,7 +173,8 @@ sub mark_as_open {
         my $header = muse_fast_scan_header($self->muse_file);
         die "Not a muse file!" unless $header && %$header;
         # TODO maybe use storable?
-        $self->_write_file($lockfile, $$ . ' ' . localtime . "\n");
+        my $localtime = localtime(time());
+        $self->_write_file($lockfile, $$ . ' ' . $localtime . "\n");
         $self->_set_is_deleted($header->{DELETED});
         if ($self->is_deleted) {
             $self->purge_all;
@@ -187,7 +188,8 @@ sub mark_as_closed {
     my $lockfile = $self->lockfile;
     unlink $lockfile or die "Couldn't unlink $lockfile!";
     # TODO maybe use storable?
-    $self->_write_file($self->complete_file, $$ . ' ' . localtime . "\n");
+    my $localtime = localtime(time());
+    $self->_write_file($self->complete_file, $$ . ' ' . $localtime . "\n");
 }
 
 =head2 purge_all
